@@ -1,2 +1,3 @@
 from exponea_python_sdk.client import Exponea
-name = "exponea_python_sdk"
\ No newline at end of file
+
+name = 'exponea_python_sdk'
